@@ -15,7 +15,7 @@ from kabaret.flow_contextual_dict import ContextualView, get_contextual_dict
 from kabaret.subprocess_manager.flow import RunAction
 
 from .maputils import ItemMap, CreateGenericAction, ClearMapAction, RemoveGenericAction
-from libreflow.baseflow.runners import BaseRunner, PythonRunner
+from libreflow.baseflow.runners import Runner, PythonRunner
 
 
 class StaticSiteTypeChoices(flow.values.ChoiceValue):
@@ -678,6 +678,18 @@ class GotoQueue(flow.Action):
         return self.get_result(goto=self._site.queue.oid())
 
 
+class GotoCurrentSiteQueue(flow.Action):
+    
+    ICON = ('icons.flow', 'jobs')
+    
+    def needs_dialog(self):
+        return False
+    
+    def run(self, button):
+        current_site = self.root().project().get_current_site()
+        return self.get_result(goto=current_site.queue.oid())
+
+
 class ClearQueueJobStatus(flow.values.ChoiceValue):
 
     CHOICES = JobStatus.CHOICES + ["All"]
